from __future__ import unicode_literals

from telesign.score import ScoreClient as _ScoreClient
from telesignenterprise.constants import SOURCE_SDK
import telesignenterprise
import telesign


class ScoreClient(_ScoreClient):
    """
    Score provides risk information about a specified phone number.
    """

    def __init__(
        self,
        customer_id,
        api_key,
        rest_endpoint="https://rest-ww.telesign.com",
        **kwargs
    ):
        sdk_version_origin = telesignenterprise.__version__
        sdk_version_dependency = telesign.__version__
        super(ScoreClient, self).__init__(
            customer_id,
            api_key,
            rest_endpoint=rest_endpoint,
            source=SOURCE_SDK,
            sdk_version_origin=sdk_version_origin,
            sdk_version_dependency=sdk_version_dependency,
            **kwargs
        )



from __future__ import unicode_literals

from telesign.messaging import MessagingClient as _MessagingClient
from telesignenterprise.constants import SOURCE_SDK
import telesignenterprise
import telesign

OMNI_MESSAGING_RESOURCE = "/v1/omnichannel"


class MessagingClient(_MessagingClient):
    """
    TeleSign's Messaging API allows you to easily send SMS messages. You can send alerts, reminders, and notifications,
    or you can send verification messages containing one-time passcodes (OTP).
    """

    def __init__(
        self,
        customer_id,
        api_key,
        rest_endpoint="https://rest-ww.telesign.com",
        **kwargs
    ):
        sdk_version_origin = telesignenterprise.__version__
        sdk_version_dependency = telesign.__version__
        super(MessagingClient, self).__init__(
            customer_id,
            api_key,
            rest_endpoint=rest_endpoint,
            source=SOURCE_SDK,
            sdk_version_origin=sdk_version_origin,
            sdk_version_dependency=sdk_version_dependency,
            **kwargs
        )

    """
    Send a message to the target recipient using any of Telesign's supported channels.
    @param params All required and optional parameters well-structured according to the API documentation.

    See  https://developer.telesign.com/enterprise/reference/sendadvancedmessage for detailed API documentation.
    """

    def omniMessage(self, params={}):
        return self.post(OMNI_MESSAGING_RESOURCE, json_fields=params)



from __future__ import unicode_literals

from telesign.rest import RestClient
from telesignenterprise.constants import SOURCE_SDK
import telesignenterprise
import telesign

TELEBUREAU_CREATE_RESOURCE = "/v1/telebureau/event"
TELEBUREAU_RETRIEVE_RESOURCE = "/v1/telebureau/event/{reference_id}"
TELEBUREAU_DELETE_RESOURCE = "/v1/telebureau/event/{reference_id}"


class TelebureauClient(RestClient):
    """
    TeleBureau is a service is based on TeleSign's watchlist, which is a proprietary database containing verified phone
    numbers of users known to have committed online fraud. TeleSign crowd-sources this information from its customers.
    Participation is voluntary, but you have to contribute in order to benefit.
    """

    def __init__(
        self,
        customer_id,
        api_key,
        rest_endpoint="https://rest-ww.telesign.com",
        **kwargs
    ):
        sdk_version_origin = telesignenterprise.__version__
        sdk_version_dependency = telesign.__version__
        super(TelebureauClient, self).__init__(
            customer_id,
            api_key,
            rest_endpoint=rest_endpoint,
            source=SOURCE_SDK,
            sdk_version_origin=sdk_version_origin,
            sdk_version_dependency=sdk_version_dependency,
            **kwargs
        )

    def create_event(self, phone_number, fraud_type, occurred_at, **params):
        """
        Creates a telebureau event corresponding to supplied data.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.post(
            TELEBUREAU_CREATE_RESOURCE,
            phone_number=phone_number,
            fraud_type=fraud_type,
            occurred_at=occurred_at,
            **params
        )

    def retrieve_event(self, reference_id, **params):
        """
        Retrieves the fraud event status. You make this call in your web application after completion of create
        transaction for a telebureau event.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.get(
            TELEBUREAU_RETRIEVE_RESOURCE.format(reference_id=reference_id), **params
        )

    def delete_event(self, reference_id, **params):
        """
        Deletes a previously submitted fraud event. You make this call in your web application after completion of the
        create transaction for a telebureau event.

        See https://developer.telesign.com/docs/telebureau-api for detailed API documentation.
        """
        return self.delete(
            TELEBUREAU_DELETE_RESOURCE.format(reference_id=reference_id), **params
        )



from __future__ import unicode_literals

from telesign.phoneid import PhoneIdClient as _PhoneIdClient
from telesignenterprise.constants import SOURCE_SDK
import telesignenterprise
import telesign

PHONEID_STANDARD_RESOURCE = "/v1/phoneid/standard/{phone_number}"
PHONEID_SCORE_RESOURCE = "/v1/phoneid/score/{phone_number}"
PHONEID_LIVE_RESOURCE = "/v1/phoneid/live/{phone_number}"
PHONEID_RESOURCE = "/v1/phoneid"

class PhoneIdClient(_PhoneIdClient):
    """
    PhoneID is a set of REST APIs that deliver deep phone number data attributes that help optimize the end user
    verification process and evaluate risk.

    TeleSign PhoneID provides a wide range of risk assessment indicators on the number to help confirm user identity,
    delivering real-time decision making throughout the number lifecycle and ensuring only legitimate users are
    creating accounts and accessing your applications.
    """

    def __init__(
        self,
        customer_id,
        api_key,
        rest_endpoint="https://rest-ww.telesign.com",
        **kwargs
    ):
        sdk_version_origin = telesignenterprise.__version__
        sdk_version_dependency = telesign.__version__
        super(PhoneIdClient, self).__init__(
            customer_id,
            api_key,
            rest_endpoint=rest_endpoint,
            source=SOURCE_SDK,
            sdk_version_origin=sdk_version_origin,
            sdk_version_dependency=sdk_version_dependency,
            **kwargs
        )

    def standard(self, phone_number, **params):
        """
        The PhoneID Standard API that provides phone type and telecom carrier information to identify which phone
        numbers can receive SMS messages and/or a potential fraud risk.

        See https://developer.telesign.com/docs/rest_phoneid-standard for detailed API documentation.
        """
        return self.get(
            PHONEID_STANDARD_RESOURCE.format(phone_number=phone_number), **params
        )

    def score(self, phone_number, ucid, **params):
        """
        Score is an API that delivers reputation scoring based on phone number intelligence, traffic patterns, machine
        learning, and a global data consortium.

        See https://developer.telesign.com/docs/rest_api-phoneid-score for detailed API documentation.
        """
        return self.get(
            PHONEID_SCORE_RESOURCE.format(phone_number=phone_number),
            ucid=ucid,
            **params
        )

    def live(self, phone_number, ucid, **params):
        """
        The PhoneID Live API delivers insights such as whether a phone is active or disconnected, a device is reachable
        or unreachable and its roaming status.

        See https://developer.telesign.com/docs/rest_api-phoneid-live for detailed API documentation.
        """
        return self.get(
            PHONEID_LIVE_RESOURCE.format(phone_number=phone_number), ucid=ucid, **params
        )
    
    def phone_id_path(self,phone_number,**params):
        """
        Returns detailed information about a phone number, including its carrier, location, and more, by providing the phone number in the request body.
        See https://developer.telesign.com/enterprise/reference/submitphonenumberforidentity for detailed API documentation.
        """
        if params == {} or params is None:
            params = {}
        if "consent" not in params:
            params["consent"] = {"method" : 1}
        resource_path = f"{PHONEID_RESOURCE}"'/'f"{phone_number}"
        return self.post(
            resource_path,
            **params)
    
    def phone_id_body(self,phone_number,**params):
        """
        Returns detailed information about a phone number, including its carrier, location, and more, by providing the phone number in the request body.
        See https://developer.telesign.com/enterprise/reference/submitphonenumberforidentityalt for detailed API documentation.
        """
        if params == {} or params is None:
            params = {}
        params["phone_number"] = phone_number
        if "consent" not in params:
            params["consent"] = {"method" : 1}
        self.auth_method = 'Basic'
        return self.post(
            PHONEID_RESOURCE,
            params)


from setuptools import setup, find_packages

version = "3.0.0"

try:
    with open("README") as f:
        readme_content = f.read()
except (IOError, Exception):
    readme_content = ""

setup(name='telesignenterprise',
      version=version,
      description="Telesign Enterprise SDK",
      license="MIT License",
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "Intended Audience :: Developers",
          "License :: OSI Approved :: MIT License",
          "Natural Language :: English",
          "Programming Language :: Python",
          "Programming Language :: Python :: 2.6",
          "Programming Language :: Python :: 2.7",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3.3",
          "Programming Language :: Python :: 3.4",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
      ],
      long_description=readme_content,
      keywords='telesign, sms, voice, mobile, authentication, identity, messaging',
      author='TeleSign Corp.',
      author_email='support@telesign.com',
      url="https://github.com/telesign/python_telesign",
      install_requires=['telesign >=2.2.1, <=3.0.0'],
      packages=find_packages(exclude=['test', 'test.*', 'examples', 'examples.*']),
      )



from __future__ import unicode_literals

from telesign.rest import RestClient
from telesignenterprise.constants import SOURCE_SDK
import telesignenterprise
import telesign

APP_VERIFY_BASE_RESOURCE = "/v1/verify/auto/voice"
APP_VERIFY_INITIATE_RESOURCE = APP_VERIFY_BASE_RESOURCE + "/initiate"
APP_VERIFY_FINALIZE_RESOURCE = APP_VERIFY_BASE_RESOURCE + "/finalize"
APP_VERIFY_FINALIZE_CALLERID_RESOURCE = APP_VERIFY_BASE_RESOURCE + "/finalize/callerid"
APP_VERIFY_FINALIZE_TIMEOUT_RESOURCE = APP_VERIFY_BASE_RESOURCE + "/finalize/timeout"
APP_VERIFY_STATUS_RESOURCE = APP_VERIFY_BASE_RESOURCE + "/{}"


class AppVerifyClient(RestClient):
    """
    The TeleSign App Verify web service enables customers to verify devices
    through a voice call by a verification code provided in the caller ID.
    """

    def __init__(
        self,
        customer_id,
        api_key,
        rest_endpoint="https://rest-ww.telesign.com",
        **kwargs
    ):
        sdk_version_origin = telesignenterprise.__version__
        sdk_version_dependency = telesign.__version__
        super(AppVerifyClient, self).__init__(
            customer_id,
            api_key,
            rest_endpoint=rest_endpoint,
            source=SOURCE_SDK,
            sdk_version_origin=sdk_version_origin,
            sdk_version_dependency=sdk_version_dependency,
            **kwargs
        )

    def initiate(self, phone_number, **params):
        """
        Use this endpont to initiate verification of the specified phone number using the Telesign App Verify API.

        :param phone_number: The phone number to verify
        :param params: Additional optional parameters
        :return: API response object

        See https://developer.telesign.com/enterprise/reference/sendappverifycode for detailed API documentation.
        """
        return self.post(
            APP_VERIFY_INITIATE_RESOURCE, phone_number=phone_number, **params
        )

    def finalize(self, reference_id, **params):
        """
        Use this endpoint to terminate a call created using the Telesign App Verify API 
        if the handset does not terminate the call in your application.

        :param reference_id: The reference ID of the verification transaction
        :param params: Additional optional parameters
        :return: API response object

        See https://developer.telesign.com/enterprise/reference/endappverifycall for detailed API documentation.
        """
        return self.post(
            APP_VERIFY_FINALIZE_RESOURCE, reference_id=reference_id, **params
        )

    def status(self, reference_id, **params):
        """
        Use this endpoint to get the status of a Telesign App Verify API request that you initiated.
        
        :param reference_id: The reference ID of the verification transaction
        :param params: Additional optional parameters
        :return: API response object

        See https://developer.telesign.com/enterprise/reference/getappverifystatus for detailed API documentation.
        """
        return self.get(APP_VERIFY_STATUS_RESOURCE.format(reference_id), **params)
    
    def report_unknown_callerid(self, reference_id, unknown_caller_id):
        """
        If a Telesign App Verify API call is unsuccessful, the device will not receive the call. 
        If there is a prefix sent by Telesign in the initiate request and it cannot be matched to the CLI of the verification call, 
        you can use use this endpoint to report the issue to Telesign for troubleshooting.

        :param reference_id: The reference ID of the verification transaction
        :param unknown_caller_id: The unknown caller ID to report
        :return: API response object

        See https://developer.telesign.com/enterprise/reference/reportappverifycallerid for detailed API documentation.
        """
        params = {
            "reference_id": reference_id,
            "unknown_caller_id": unknown_caller_id,
        }
        return self.post(APP_VERIFY_FINALIZE_CALLERID_RESOURCE, **params)

    def report_timeout(self, reference_id):
        """
        Use this endpont to initiate verification of the specified phone number using the Telesign App Verify API.

        :param reference_id: The reference ID of the verification transaction
        :return: API response object

        See https://developer.telesign.com/enterprise/reference/reportappverifytimeout for detailed API documentation.
        """
        params = {
            "reference_id": reference_id,
        }
        return self.post(APP_VERIFY_FINALIZE_TIMEOUT_RESOURCE, **params)